@@ -117,16 +117,18 @@ unsigned int find_button_by_position( int x, int y );
 void press_winlist_button( ASWindowData *wd );
 void release_winlist_button( ASWindowData *wd, int button );
 void update_winlist_styles();
+void DeadPipe(int);
 
 int
 main( int argc, char **argv )
 {
     /* Save our program name - for error messages */
+	set_DeadPipe_handler(DeadPipe);
     InitMyApp (CLASS_WINLIST, argc, argv, NULL, NULL, 0 );
 
     set_signal_handler( SIGSEGV );
 
-    ConnectX( &Scr, PropertyChangeMask|EnterWindowMask );
+    ConnectX( ASDefaultScr, PropertyChangeMask|EnterWindowMask );
     ConnectAfterStep (M_FOCUS_CHANGE |
                       M_DESTROY_WINDOW |
                       WINDOW_CONFIG_MASK |
@@ -378,11 +380,8 @@ process_message (send_data_type type, send_data_type *body)
 
 	if( type == M_END_WINDOWLIST )
 	{
-		if( WinListState.postpone_display ) 
-		{	
-			WinListState.postpone_display = False ;
-			rearrange_winlist_window( False );
-		}
+		WinListState.postpone_display = False ;
+		rearrange_winlist_window( False );
 	}else if( (type&WINDOW_PACKET_MASK) != 0 )
 	{
 		struct ASWindowData *wd = fetch_window_by_id( body[0] );
@@ -547,7 +546,7 @@ make_winlist_window()
 	shints.win_gravity = Config->gravity ;
 
 	extwm_hints.pid = getpid();
-	extwm_hints.flags = EXTWM_PID|EXTWM_StateSkipTaskbar|EXTWM_StateSkipPager|EXTWM_TypeDock ;
+	extwm_hints.flags = EXTWM_PID|EXTWM_StateSkipTaskbar|EXTWM_StateSkipPager|EXTWM_TypeDock|EXTWM_TypeASModule ;
 
 	set_client_hints( w, NULL, &shints, AS_DoesWmDeleteWindow, &extwm_hints );
 
@@ -613,13 +612,6 @@ rearrange_winlist_window( Bool dont_resize_main_canvas )
     LOCAL_DEBUG_CALLER_OUT( "%sresize canvas. windows_num = %d",
                             dont_resize_main_canvas?"Don't ":"Do ", WinListState.windows_num );
     
-	timer_remove_all();
-	if( WinListState.last_message_time+1 >= time(NULL) ) 
-	{	
-		timer_new (500, postponed_rearrange_winlist, (void*)dont_resize_main_canvas);	  
-		return False;
-	}
-	
 	if( dont_resize_main_canvas )
     {
         LOCAL_DEBUG_OUT( "Main_canvas geometry = %dx%d", WinListState.main_canvas->width, WinListState.main_canvas->height );
